==> haskell-ieee754-0.8.0-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ieee754.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ieee754
version:              0.8.0
visibility:           public
id:                   ieee754-0.8.0-EXeeyTii0hq1uhkX1pvfZc
key:                  ieee754-0.8.0-EXeeyTii0hq1uhkX1pvfZc
license:              BSD-3-Clause
copyright:            (c) 2011-2016. Patrick Perry <patperry@gmail.com>
maintainer:           Patrick Perry <patperry@gmail.com>
author:               Patrick Perry
homepage:             http://github.com/patperry/hs-ieee754
synopsis:             Utilities for dealing with IEEE floating point numbers
description:
    Utilities for dealing with IEEE floating point numbers, ported
    from the Tango math library; approximate and exact equality
    comparisons for general types.

category:             Math
abi:                  2419b2ff9f9cb363101f554fa240a43a
exposed:              True
exposed-modules:      Data.AEq Numeric.IEEE
import-dirs:          /usr/lib/ghc-8.8.3/site-local/ieee754-0.8.0
library-dirs:         /usr/lib/ghc-8.8.3/site-local/ieee754-0.8.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/ieee754-0.8.0
hs-libraries:         HSieee754-0.8.0-EXeeyTii0hq1uhkX1pvfZc
depends:              base-4.13.0.0
haddock-interfaces:   /usr/share/doc/haskell-ieee754/html/ieee754.haddock
haddock-html:         /usr/share/doc/haskell-ieee754/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ieee754-0.8.0-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ieee754.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ieee754
version:              0.8.0
visibility:           public
id:                   ieee754-0.8.0-KMHK0GtLIS3IfVtQsAJj3f
key:                  ieee754-0.8.0-KMHK0GtLIS3IfVtQsAJj3f
license:              BSD-3-Clause
copyright:            (c) 2011-2016. Patrick Perry <patperry@gmail.com>
maintainer:           Patrick Perry <patperry@gmail.com>
author:               Patrick Perry
homepage:             http://github.com/patperry/hs-ieee754
synopsis:             Utilities for dealing with IEEE floating point numbers
description:
    Utilities for dealing with IEEE floating point numbers, ported
    from the Tango math library; approximate and exact equality
    comparisons for general types.

category:             Math
abi:                  6a6a986fc4b0d01da3008c371c6d9785
exposed:              True
exposed-modules:      Data.AEq Numeric.IEEE
import-dirs:          /usr/lib/ghc-8.10.1/site-local/ieee754-0.8.0
library-dirs:         /usr/lib/ghc-8.10.1/site-local/ieee754-0.8.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/ieee754-0.8.0
hs-libraries:         HSieee754-0.8.0-KMHK0GtLIS3IfVtQsAJj3f
depends:              base-4.14.0.0
haddock-interfaces:   /usr/share/doc/haskell-ieee754/html/ieee754.haddock
haddock-html:         /usr/share/doc/haskell-ieee754/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
